@@ -17,8 +17,10 @@ main :: IO ()
 main = hspec spec
 
 forFIFO :: ([Int] -> IO ()) -> F.Args Int [Int]
-forFIFO cb = F.Args {
-  F.cb = cb, F.fold = (\l v -> l ++ [v]), F.init = []
+forFIFO cb = F.Args
+  { F.cb = cb
+  , F.fold = \l v -> l ++ [v]
+  , F.init = []
   }
 
 callbackToTChan :: TChan a -> a -> IO ()
@@ -26,12 +28,12 @@ callbackToTChan output = atomically . writeTChan output
 
 fifoTrigger :: F.Opts Int [Int] -> IO (F.Trigger Int [Int], TChan [Int])
 fifoTrigger opts = do
-  output <- atomically $ newTChan
+  output <- atomically newTChan
   trig <- F.new (forFIFO $ callbackToTChan output) opts
   return (trig, output)
 
 repeatFor :: Integer -> IO () -> IO ()
-repeatFor duration_usec action = repeatUntil =<< (addUTCTime (fromRational (duration_usec % 1000000)) <$> getCurrentTime)
+repeatFor duration_usec action = repeatUntil . addUTCTime (fromRational (duration_usec % 1000000)) =<< getCurrentTime
   where
     repeatUntil goal_time = do
       action
@@ -122,7 +124,7 @@ spec = do
                                      F.UnexpectedClosedException _ -> True
                                      _                             -> False)
     it "folds input events strictly" $ do
-      output <- atomically $ newTChan
+      output <- atomically newTChan
       trig <- F.new F.Args { F.cb = callbackToTChan output, F.fold = (+), F.init = 0 }
                     F.def { F.delay = 100000 }
       F.send trig 10
@@ -134,7 +136,7 @@ spec = do
                                         F.UnexpectedClosedException _ -> True
                                         _                             -> False)
     it "emits output events even if input events are coming intensely" $ do
-      output <- atomically $ newTChan
+      output <- atomically newTChan
       trig <- F.new F.Args { F.cb = callbackToTChan output, F.fold = (\_ i -> i), F.init = "" }
                     F.def { F.delay = 500 }
       repeatFor 2000 $ F.send trig "abc"
@@ -143,7 +145,7 @@ spec = do
       output_events `shouldSatisfy` ((> 2) . length)
   describe "forStack" $ do
     it "creates a stacked FoldDebounce" $ do
-      output <- atomically $ newTChan
+      output <- atomically newTChan
       trig <- F.new (F.forStack $ callbackToTChan output)
                     F.def { F.delay = 50000 }
       F.send trig 10
@@ -153,7 +155,7 @@ spec = do
       F.close trig
   describe "forMonoid" $ do
     it "creates a FoldDebounce for Monoids" $ do
-      output <- atomically $ newTChan
+      output <- atomically newTChan
       trig <- F.new (F.forMonoid $ callbackToTChan output)
                     F.def { F.delay = 50000 }
       F.send trig [10]
@@ -163,7 +165,7 @@ spec = do
       F.close trig
   describe "forVoid" $ do
     it "discards input events, but starts the timer" $ do
-      output <- atomically $ newTChan
+      output <- atomically newTChan
       trig <- F.new (F.forVoid $ callbackToTChan output "hoge")
               F.def { F.delay = 50000 }
       F.send trig "foo1"
